==> amx-javaee-4.0-b33-sources.jar: org/glassfish/admin/amx/impl/j2ee/J2EEDeployedObjectImplBase.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.amx.impl.j2ee;

import org.glassfish.admin.amx.j2ee.J2EEDeployedObject;

import javax.management.ObjectName;

/**
 */
public class J2EEDeployedObjectImplBase extends J2EEManagedObjectImplBase // implements J2EEDeployedObject
{
    public J2EEDeployedObjectImplBase(
            final ObjectName parentObjectName,
            final Metadata meta,
            final Class<? extends J2EEDeployedObject> intf) {
        super(parentObjectName, meta, intf);
    }

    public String getdeploymentDescriptor() {
        return metadata().getDeploymentDescriptor();
    }

    public String getserver() {
        return getServerObjectName().toString();
    }

    public void start() {
        checkstateManageable();
    //getDelegate().invoke( "start", null, null );
    }

    public void startRecursive() {
        start();
    }

    public void stop() {
        checkstateManageable();
    //getDelegate().invoke( "stop", null, null );
    }

    private void checkstateManageable() {
        if (!isstateManageable()) {
            throw new UnsupportedOperationException("stateManageable is false");
        }
    }
}

==> amx-javaee-5.0.1-sources.jar: org/glassfish/admin/amx/impl/j2ee/J2EEDeployedObjectImplBase.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.amx.impl.j2ee;

import org.glassfish.admin.amx.j2ee.J2EEDeployedObject;

import javax.management.ObjectName;

/**
 */
public class J2EEDeployedObjectImplBase extends J2EEManagedObjectImplBase // implements J2EEDeployedObject
{
    public J2EEDeployedObjectImplBase(
            final ObjectName parentObjectName,
            final Metadata meta,
            final Class<? extends J2EEDeployedObject> intf) {
        super(parentObjectName, meta, intf);
    }

    public String getdeploymentDescriptor() {
        /*
         * FindBugs warns about the confusing mismatch between this method's
         * name and the name of the method it invokes.  This method - and
         * getserver below - are intended this way.
         */
        return metadata().getDeploymentDescriptor();
    }

    public String getserver() {
        return getServerObjectName().toString();
    }

    public void start() {
        checkstateManageable();
    //getDelegate().invoke( "start", null, null );
    }

    public void startRecursive() {
        start();
    }

    public void stop() {
        checkstateManageable();
    //getDelegate().invoke( "stop", null, null );
    }

    private void checkstateManageable() {
        if (!isstateManageable()) {
            throw new UnsupportedOperationException("stateManageable is false");
        }
    }
}
